@@ -2,7 +2,7 @@
 
 import argparse
 import io
-import json
+import ujson
 import logging
 import os
 import sys
@@ -55,7 +55,7 @@ def add_metadata_columns_to_schema(schema_message):
 def emit_state(state: Optional[Dict]):
     """Print state to stdout"""
     if state is not None:
-        line = json.dumps(state)
+        line = ujson.dumps(state)
         LOGGER.info('Emitting state %s', line)
         sys.stdout.write(f"{line}\n")
         sys.stdout.flush()
@@ -120,8 +120,8 @@ def persist_lines(config, lines, table_cache=None, file_format_type: FileFormatT
     # Loop over lines from stdin
     for line in lines:
         try:
-            o = json.loads(line)
-        except json.decoder.JSONDecodeError:
+            o = ujson.loads(line)
+        except ValueError:
             LOGGER.error('Unable to parse:\n%s', line)
             raise
 
@@ -240,13 +240,19 @@ def persist_lines(config, lines, table_cache=None, file_format_type: FileFormatT
                 # if same stream has been encountered again, it means the schema might have been altered
                 # so previous records need to be flushed
                 if row_count.get(stream, 0) > 0:
+                    # flush all streams, delete records if needed, reset counts and then emit current state
+                    if config.get('flush_all_streams'):
+                        filter_streams = None
+                    else:
+                        filter_streams = [stream]
                     flushed_state = flush_streams(records_to_load,
                                                   row_count,
                                                   stream_to_sync,
                                                   config,
                                                   state,
                                                   flushed_state,
-                                                  archive_load_files_data)
+                                                  archive_load_files_data,
+                                                  filter_streams=filter_streams)
 
                     # emit latest encountered state
                     emit_state(flushed_state)
@@ -508,7 +514,7 @@ def main():
 
     if args.config:
         with open(args.config, encoding="utf8") as config_input:
-            config = json.load(config_input)
+            config = ujson.load(config_input)
     else:
         config = {}
 
